==> jc-1.4.0.tar.gz: soot/tagkit/KeyTag.h <==
// public class soot.tagkit.KeyTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9cb4881430c5d3aa soot_tagkit_KeyTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_KeyTag_H_
#define _JC_soot_tagkit_KeyTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_KeyTag$sub_refs	_jc_soot_tagkit_KeyTag$sub_refs;
typedef struct _jc_soot_tagkit_KeyTag$sub_nonrefs	_jc_soot_tagkit_KeyTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_KeyTag$refs	_jc_soot_tagkit_KeyTag$refs;
typedef struct _jc_soot_tagkit_KeyTag$nonrefs	_jc_soot_tagkit_KeyTag$nonrefs;
typedef struct _jc_soot_tagkit_KeyTag$object	_jc_soot_tagkit_KeyTag$object;

typedef const struct _jc_soot_tagkit_KeyTag$vmethods	_jc_soot_tagkit_KeyTag$vmethods;
typedef const struct _jc_soot_tagkit_KeyTag$vtable	_jc_soot_tagkit_KeyTag$vtable;
typedef const struct _jc_soot_tagkit_KeyTag$vtype	_jc_soot_tagkit_KeyTag$vtype;

// Constructors
extern void _jc_soot_tagkit_KeyTag$method$_init$7a03d5d0a68a368a(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *, jint, jint, jint, struct _jc_java_lang_String$object *);
extern void _jc_soot_tagkit_KeyTag$method$_init$206934d97c5ba451(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_soot_tagkit_KeyTag$method$blue$b7dee708615eaa32(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_KeyTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_KeyTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
extern jint _jc_soot_tagkit_KeyTag$method$green$53ef4b741280a296(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_KeyTag$method$key$dd25a381b3eaf34c(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
extern jint _jc_soot_tagkit_KeyTag$method$red$7d0da69269fa97dd(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$blue$b7dee708615eaa32;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$green$53ef4b741280a296;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$key$dd25a381b3eaf34c;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$red$7d0da69269fa97dd;

// Virtual methods structure
struct _jc_soot_tagkit_KeyTag$vmethods {
	jint	(*blue$b7dee708615eaa32)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
	jint	(*green$53ef4b741280a296)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
	struct _jc_java_lang_String$object	*(*key$dd25a381b3eaf34c)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
	jint	(*red$7d0da69269fa97dd)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *);
};

// Vtable
struct _jc_soot_tagkit_KeyTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_KeyTag$vmethods	soot_tagkit_KeyTag;
};

// Vtype
struct _jc_soot_tagkit_KeyTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_KeyTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_KeyTag$sub_refs {
	struct _jc_java_lang_String$object	*key;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_KeyTag$refs {
    _jc_soot_tagkit_KeyTag$sub_refs	soot_tagkit_KeyTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_KeyTag$sub_nonrefs {
	jint	red;
	jint	green;
	jint	blue;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_KeyTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_KeyTag$sub_nonrefs	soot_tagkit_KeyTag;
};

// Object instance structure
struct _jc_soot_tagkit_KeyTag$object {
	_jc_soot_tagkit_KeyTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_KeyTag$vtype	*vtype;
	_jc_soot_tagkit_KeyTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_KeyTag$vtype _jc_soot_tagkit_KeyTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_KeyTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_KeyTag$class_object;

#endif	/* _JC_soot_tagkit_KeyTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/KeyTag.h <==
// public class soot.tagkit.KeyTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9cb4881430c5d3aa soot_tagkit_KeyTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_KeyTag_H_
#define _JC_soot_tagkit_KeyTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_KeyTag$sub_refs	_jc_soot_tagkit_KeyTag$sub_refs;
typedef struct _jc_soot_tagkit_KeyTag$sub_nonrefs	_jc_soot_tagkit_KeyTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_KeyTag$refs	_jc_soot_tagkit_KeyTag$refs;
typedef struct _jc_soot_tagkit_KeyTag$nonrefs	_jc_soot_tagkit_KeyTag$nonrefs;
typedef struct _jc_soot_tagkit_KeyTag$object	_jc_soot_tagkit_KeyTag$object;

typedef const struct _jc_soot_tagkit_KeyTag$vmethods	_jc_soot_tagkit_KeyTag$vmethods;
typedef const struct _jc_soot_tagkit_KeyTag$vtable	_jc_soot_tagkit_KeyTag$vtable;
typedef const struct _jc_soot_tagkit_KeyTag$vtype	_jc_soot_tagkit_KeyTag$vtype;

// Constructors
extern void _jc_soot_tagkit_KeyTag$method$_init$7a03d5d0a68a368a(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *, jint, jint, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_tagkit_KeyTag$method$_init$206934d97c5ba451(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_tagkit_KeyTag$method$blue$b7dee708615eaa32(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_KeyTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_KeyTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_tagkit_KeyTag$method$green$53ef4b741280a296(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_KeyTag$method$key$dd25a381b3eaf34c(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_tagkit_KeyTag$method$red$7d0da69269fa97dd(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$blue$b7dee708615eaa32;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$green$53ef4b741280a296;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$key$dd25a381b3eaf34c;
extern _jc_method _jc_soot_tagkit_KeyTag$method_info$red$7d0da69269fa97dd;

// Virtual methods structure
struct _jc_soot_tagkit_KeyTag$vmethods {
	jint	(*blue$b7dee708615eaa32)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
	jint	(*green$53ef4b741280a296)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*key$dd25a381b3eaf34c)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
	jint	(*red$7d0da69269fa97dd)(_jc_env *, struct _jc_soot_tagkit_KeyTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_KeyTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_KeyTag$vmethods	soot_tagkit_KeyTag;
};

// Vtype
struct _jc_soot_tagkit_KeyTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_KeyTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_KeyTag$sub_refs {
	struct _jc_java_lang_String$object	*key;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_KeyTag$refs {
    _jc_soot_tagkit_KeyTag$sub_refs	soot_tagkit_KeyTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_KeyTag$sub_nonrefs {
	jint	red;
	jint	green;
	jint	blue;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_KeyTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_KeyTag$sub_nonrefs	soot_tagkit_KeyTag;
};

// Object instance structure
struct _jc_soot_tagkit_KeyTag$object {
	_jc_soot_tagkit_KeyTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_KeyTag$vtype	*vtype;
	_jc_soot_tagkit_KeyTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_KeyTag$vtype _jc_soot_tagkit_KeyTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_KeyTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_KeyTag$class_object;

#endif	/* _JC_soot_tagkit_KeyTag_H_ */
